	package models

// 提交订单信息
type PayOrder struct {
	MerchantId string `json:"merchantId"`
	OrderAmount string `json:"orderAmount"`
    OrderCurrency string `json:"orderCurrency"`
    RequestId string `json:"requestId"`
    Language string `json:"language"`
    NotifyUrl string `json:"notifyUrl"`
    CallbackUrl string `json:"callbackUrl"`
    ShipInfo ShipInfo `json:"shipInfo"`
    BillInfo BillInfo `json:"billInfo"`
    TerminalNo string `json:"terminalNo"`
    Remark string `json:"remark"`
    Hmac string `json:"hmac"`
}

//送货信息
type ShipInfo struct {
    ShipStreet string `json:"shipStreet"`  
    ShipCity string `json:"shipCity"`
    ShipState string `json:"shipState"`
    ShipPost string `json:"shipPost"`
    ShipCountry string `json:"shipCountry"`
    ShipPhone string `json:"shipPhone"`
    ShipEmail string `json:"shipEmail"`
}

//账单信息
type BillInfo struct {
    BillStreet string `json:"billStreet"`  
    BillCity string `json:"billCity"`
    BillState string `json:"billState"`
    BillPost string `json:"billPost"`
    BillCountry string `json:"billCountry"`
    BillPhone string `json:"billPhone"`
    BillEmail string `json:"billEmail"`
}

//订单请求后响应数据
type PayOrderBack struct{
	MerchantId string `json:"merchantId"`    
    RequestId string `json:"requestId"`
    RedirectUrl string `json:"redirectUrl"`
    ResponseObject
}

//订单通知数据
type PayOrderBacks struct{
	MerchantId string `json:"merchantId"`    
    RequestId string `json:"requestId"`
    BankNumber string `json:"bankNumber"`
    SerialNumber string `json:"serialNumber"`
    Pstatus string `json:"pstatus"`
    PstatusDescription string `json:"pstatusDescription"`
    OrderAmount string `json:"orderAmount"`
    OrderCurrency string `json:"orderCurrency"`
    SubmissionTime string `json:"submissionTime"`
    CompleteTime string `json:"completeTime"`
    PaymentModeAlias string `json:"paymentModeAlias"`
    Remark string `json:"remark"`
    ResponseObject
}

// 提交查询订单信息
type QueryOrder struct {
	MerchantId string `json:"merchantId"`
    RequestId string `json:"requestId"`
    Hmac string `json:"hmac"`
}

//查询订单响应内容
type QueryOrderBack struct{
	Pstatus string `json:"pstatus"`
    PstatusDescription string `json:"pstatusDescription"`
	MerchantId string `json:"merchantId"`    
    PaymentModeAlias string `json:"paymentModeAlias"`
    RequestId string `json:"requestId"`
    BankNumber string `json:"bankNumber"`
    SerialNumber string `json:"serialNumber"`
    OrderAmount string `json:"orderAmount"`
    OrderCurrency string `json:"orderCurrency"`
    SubmissionTime string `json:"submissionTime"`
    CompleteTime string `json:"completeTime"`
    TotalRefundCount string `json:"totalRefundCount"`
    TotalRefundAmount string `json:"totalRefundAmount"`
    RefundDetails []RefundDetail `json:"refundDetails"`
    TotalRefuseCount string `json:"totalRefuseCount"`
    TotalRefuseAmount string `json:"totalRefuseAmount"`
    RefuseDetails []RefuseDetail `json:"refuseDetails"`
    Remark string `json:"remark"`
    ResponseObject
}
//退款详情
type RefundDetail struct{
	RefundId string `json:"refundId"`
    BankNumber string `json:"bankNumber"`
	RefundAmount string `json:"refundAmount"`    
    RefundSubmissionTime string `json:"refundSubmissionTime"`
    RefundCompleteTime string `json:"refundCompleteTime"`
}
//拒付详情
type RefuseDetail struct{
	RefuseId string `json:"refuseId"`
    BankNumber string `json:"bankNumber"`
	RefuseAmount string `json:"refuseAmount"`    
    RefuseCompleteTime string `json:"refuseCompleteTime"`
}
// 提交退款订单信息
type RefundOrder struct {
	MerchantId string `json:"merchantId"`
	OrderRequestId string `json:"orderRequestId"`
    RequestId string `json:"requestId"`//商户自定义请求号，不能重复
    Amount string `json:"amount"`
    NotifyUrl string `json:"notifyUrl"`
    Remark string `json:"remark"`
    Hmac string `json:"hmac"`
}

//退款订单响应内容
type RefundOrderBack struct{
	MerchantId string `json:"merchantId"`    
    OrderRequestId string `json:"orderRequestId"`
    RequestId string `json:"requestId"`//商户自定义请求号，不能重复
    BankNumber string `json:"bankNumber"`   
    RefundId string `json:"refundId"`    
    Amount string `json:"amount"` 
    Currency string `json:"currency"`
    RefundSubmissionTime string `json:"refundSubmissionTime"`
    Remark string `json:"remark"`
    ResponseObject
}
//退款订单异步通知内容
type RefundOrderBacks struct{
	MerchantId string `json:"merchantId"`  
	OrderRequestId string `json:"orderRequestId"`  
    RequestId string `json:"requestId"`
    BankNumber string `json:"bankNumber"`   
    RefundId string `json:"refundId"`   
    RefundStatus string `json:"refundStatus"`  
    Amount string `json:"amount"` 
    Currency string `json:"currency"`
    RefundSubmissionTime string `json:"refundSubmissionTime"`
    RefundCompleteTime string `json:"refundCompleteTime"`
    Remark string `json:"remark"`
    ResponseObject
}
// 提交查询退款订单信息
type QueryRefund struct {
	MerchantId string `json:"merchantId"`
    RequestId string `json:"requestId"`
    Hmac string `json:"hmac"`
}

//查询退款订单响应内容
type QueryRefundBack struct{
	MerchantId string `json:"merchantId"`  
	OrderRequestId string `json:"orderRequestId"`  
    RequestId string `json:"requestId"`   
    RefundId string `json:"refundId"`  
    BankNumber string `json:"bankNumber"` 
    RefundStatus string `json:"refundStatus"`  
    Amount string `json:"amount"` 
    Currency string `json:"currency"`
    RefundSubmissionTime string `json:"refundSubmissionTime"`
    RefundCompleteTime string `json:"refundCompleteTime"`
    Remark string `json:"remark"`
    ResponseObject
}
//拒付异步通知
type RefuseBack struct{
	MerchantId string `json:"merchantId"`  
	RequestId string `json:"requestId"`
    BankNumber string `json:"bankNumber"`   
    RefuseId string `json:"refuseId"`   
    Amount string `json:"amount"` 
    Currency string `json:"currency"`
    RefuseCompleteTime string `json:"refuseCompleteTime"`
    ResponseObject
}